@@ -131,8 +131,6 @@
 #undef HAVE_SCHED_YIELD
 /* whether we have a working sem_init()                                 */
 #undef HAVE_SEM_INIT
-/* whether we have read/write locks                                     */
-#undef HAVE_POSIX_RWLOCK
 /* whether we have mutex lock operations with timeout                   */
 #undef HAVE_PTHREAD_MUTEX_TIMEDLOCK
 /* whether we can set the clock for timed waits on condition variables  */
@@ -180,13 +178,16 @@
 #endif
 
 #undef FILE_CNT
-#if 2 == 1
+#if defined(__OpenBSD__)
+#  define FILE_CNT(fp)  (__freadahead((fp)))
+#endif
+#if 0 == 1
 #  define FILE_CNT(fp)  ((fp)->_IO_read_end - (fp)->_IO_read_ptr)
 #endif
-#if 2 == 2
+#if 0 == 2
 #  define FILE_CNT(fp)  ((fp)->_r)
 #endif
-#if 2 == 3
+#if 0 == 3
 #  define FILE_CNT(fp)  ((fp)->_cnt)
 #endif
 
@@ -200,7 +201,7 @@
 #  define PATH_SEPARATOR        ':'
 #endif
 
-#define ECL_ARCHITECTURE "AARCH64_BE"
+#define ECL_ARCHITECTURE "I386"
 
 #ifdef ECL_AVOID_FPE_H
 # define ecl_detect_fpe()
