@@ -2,19 +2,14 @@
 /* vim: set filetype=c tabstop=8 shiftwidth=4 expandtab: */
 
 /*
-    config.h.in -- Template configuration file.
-*/
-/*
-    Copyright (c) 1990, Giuseppe Attardi.
-    Copyright (c) 2001, Juan Jose Garcia Ripoll.
+ * Copyright (c) 1990, Giuseppe Attardi.
+ * Copyright (c) 2001, Juan Jose Garcia Ripoll.
+ *
+ * See file 'LICENSE' for the copyright details.
+ *
+ */
 
-    ECoLisp is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    See file '../Copyright' for full details.
-*/
+/* config.h.in -- Template configuration file. */
 
 #if defined(_MSC_VER) || defined(__MINGW32__) || __WIN32__ || __WIN64__
 #define ECL_MS_WINDOWS_HOST
@@ -47,7 +42,7 @@
 #endif
 
 /* Decimal number made with the formula yymmvv */
-#define ECL_VERSION_NUMBER 230909
+#define ECL_VERSION_NUMBER 240510
 
 /*
  * FEATURES LINKED IN
@@ -140,16 +135,16 @@
  * use autoconf to guess the following values.
  */
 #define ECL_INT_BITS            32
-#define ECL_LONG_BITS           64
-#define ECL_FIXNUM_BITS         64
-#define MOST_POSITIVE_FIXNUM    ((cl_fixnum)2305843009213693951L)
-#define MOST_NEGATIVE_FIXNUM    ((cl_fixnum)-2305843009213693952L)
-#define MOST_POSITIVE_FIXNUM_VAL 2305843009213693951L
-#define MOST_NEGATIVE_FIXNUM_VAL -2305843009213693952L
+#define ECL_LONG_BITS           32
+#define ECL_FIXNUM_BITS         32
+#define MOST_POSITIVE_FIXNUM    ((cl_fixnum)536870911)
+#define MOST_NEGATIVE_FIXNUM    ((cl_fixnum)-536870912)
+#define MOST_POSITIVE_FIXNUM_VAL 536870911
+#define MOST_NEGATIVE_FIXNUM_VAL -536870912
 
-typedef long int cl_fixnum;
-typedef unsigned long int cl_index;
-typedef unsigned long int cl_hashkey;
+typedef int cl_fixnum;
+typedef unsigned int cl_index;
+typedef unsigned int cl_hashkey;
 
 #define ECL_BIGNUM_REGISTER_NUMBER 3
 
@@ -165,8 +160,8 @@ typedef unsigned char ecl_base_char;
  */
 #define ECL_ARRAY_RANK_LIMIT 64 /*  array rank limit            */
 #ifdef GBC_BOEHM
-#define ECL_ARRAY_DIMENSION_LIMIT 2305843009213693951L
-#define ECL_ARRAY_TOTAL_LIMIT 2305843009213693951L
+#define ECL_ARRAY_DIMENSION_LIMIT 536870911
+#define ECL_ARRAY_TOTAL_LIMIT 536870911
 #else
 #define ECL_ARRAY_DIMENSION_LIMIT 16*1024*1024
 #define ECL_ARRAY_TOTAL_LIMIT 16*1024*1024
@@ -235,6 +230,9 @@ typedef unsigned char ecl_base_char;
 /* wide-strings are available */
 #undef HAVE_WCHAR_H
 
+/* whether we have read/write locks                                     */
+#undef HAVE_POSIX_RWLOCK
+
 /*
  * C macros for inlining, denoting probable code paths and other stuff
  * that makes better code. Most of it is GCC specific.
