@@ -2,19 +2,13 @@
 /* vim: set filetype=c tabstop=8 shiftwidth=4 expandtab: */
 
 /*
-    math_msvc_fenv.h -- fake fenv.h using Microsoft Visual C++
-*/
-/*
-    Copyright (c) 2010, Juan Jose Garcia Ripoll.
-
-    ECL is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    See file '../../Copyright' for full details.
-*/
+ * Copyright (c) 2010, Juan Jose Garcia Ripoll.
+ *
+ * See file 'LICENSE' for the copyright details.
+ *
+ */
 
+/* math_msvc_fenv.h -- fake fenv.h using Microsoft Visual C++ */
 #ifndef ECL_MATH_FENV_MSVC_H
 #define ECL_MATH_FENV_MSVC_H
 
